==> diff2html-3.1.2.jar: META-INF/resources/webjars/diff2html/3.1.2/lib-esm/ui/js/highlight.js-slim.js <==
import highlightJS from 'highlight.js/lib/highlight.js';
import cpp from 'highlight.js/lib/languages/cpp';
import xml from 'highlight.js/lib/languages/xml';
import awk from 'highlight.js/lib/languages/awk';
import bash from 'highlight.js/lib/languages/bash';
import clojure from 'highlight.js/lib/languages/clojure';
import clojureRepl from 'highlight.js/lib/languages/clojure-repl';
import cmake from 'highlight.js/lib/languages/cmake';
import coffeescript from 'highlight.js/lib/languages/coffeescript';
import crystal from 'highlight.js/lib/languages/crystal';
import cs from 'highlight.js/lib/languages/cs';
import csp from 'highlight.js/lib/languages/csp';
import css from 'highlight.js/lib/languages/css';
import d from 'highlight.js/lib/languages/d';
import markdown from 'highlight.js/lib/languages/markdown';
import dart from 'highlight.js/lib/languages/dart';
import diff from 'highlight.js/lib/languages/diff';
import django from 'highlight.js/lib/languages/django';
import dockerfile from 'highlight.js/lib/languages/dockerfile';
import elixir from 'highlight.js/lib/languages/elixir';
import elm from 'highlight.js/lib/languages/elm';
import ruby from 'highlight.js/lib/languages/ruby';
import erb from 'highlight.js/lib/languages/erb';
import erlangRepl from 'highlight.js/lib/languages/erlang-repl';
import erlang from 'highlight.js/lib/languages/erlang';
import excel from 'highlight.js/lib/languages/excel';
import fsharp from 'highlight.js/lib/languages/fsharp';
import go from 'highlight.js/lib/languages/go';
import gradle from 'highlight.js/lib/languages/gradle';
import groovy from 'highlight.js/lib/languages/groovy';
import handlebars from 'highlight.js/lib/languages/handlebars';
import haskell from 'highlight.js/lib/languages/haskell';
import htmlbars from 'highlight.js/lib/languages/htmlbars';
import http from 'highlight.js/lib/languages/http';
import ini from 'highlight.js/lib/languages/ini';
import java from 'highlight.js/lib/languages/java';
import javascript from 'highlight.js/lib/languages/javascript';
import json from 'highlight.js/lib/languages/json';
import julia from 'highlight.js/lib/languages/julia';
import juliaRepl from 'highlight.js/lib/languages/julia-repl';
import kotlin from 'highlight.js/lib/languages/kotlin';
import less from 'highlight.js/lib/languages/less';
import lisp from 'highlight.js/lib/languages/lisp';
import llvm from 'highlight.js/lib/languages/llvm';
import lua from 'highlight.js/lib/languages/lua';
import makefile from 'highlight.js/lib/languages/makefile';
import mathematica from 'highlight.js/lib/languages/mathematica';
import matlab from 'highlight.js/lib/languages/matlab';
import perl from 'highlight.js/lib/languages/perl';
import nginx from 'highlight.js/lib/languages/nginx';
import nix from 'highlight.js/lib/languages/nix';
import objectivec from 'highlight.js/lib/languages/objectivec';
import ocaml from 'highlight.js/lib/languages/ocaml';
import pgsql from 'highlight.js/lib/languages/pgsql';
import php from 'highlight.js/lib/languages/php';
import plaintext from 'highlight.js/lib/languages/plaintext';
import powershell from 'highlight.js/lib/languages/powershell';
import properties from 'highlight.js/lib/languages/properties';
import protobuf from 'highlight.js/lib/languages/protobuf';
import puppet from 'highlight.js/lib/languages/puppet';
import python from 'highlight.js/lib/languages/python';
import r from 'highlight.js/lib/languages/r';
import reasonml from 'highlight.js/lib/languages/reasonml';
import rust from 'highlight.js/lib/languages/rust';
import scala from 'highlight.js/lib/languages/scala';
import scheme from 'highlight.js/lib/languages/scheme';
import scss from 'highlight.js/lib/languages/scss';
import shell from 'highlight.js/lib/languages/shell';
import sql from 'highlight.js/lib/languages/sql';
import stylus from 'highlight.js/lib/languages/stylus';
import swift from 'highlight.js/lib/languages/swift';
import yaml from 'highlight.js/lib/languages/yaml';
import tex from 'highlight.js/lib/languages/tex';
import typescript from 'highlight.js/lib/languages/typescript';
import vim from 'highlight.js/lib/languages/vim';
highlightJS.registerLanguage('cpp', cpp);
highlightJS.registerLanguage('xml', xml);
highlightJS.registerLanguage('awk', awk);
highlightJS.registerLanguage('bash', bash);
highlightJS.registerLanguage('clojure', clojure);
highlightJS.registerLanguage('clojure-repl', clojureRepl);
highlightJS.registerLanguage('cmake', cmake);
highlightJS.registerLanguage('coffeescript', coffeescript);
highlightJS.registerLanguage('crystal', crystal);
highlightJS.registerLanguage('cs', cs);
highlightJS.registerLanguage('csp', csp);
highlightJS.registerLanguage('css', css);
highlightJS.registerLanguage('d', d);
highlightJS.registerLanguage('markdown', markdown);
highlightJS.registerLanguage('dart', dart);
highlightJS.registerLanguage('diff', diff);
highlightJS.registerLanguage('django', django);
highlightJS.registerLanguage('dockerfile', dockerfile);
highlightJS.registerLanguage('elixir', elixir);
highlightJS.registerLanguage('elm', elm);
highlightJS.registerLanguage('ruby', ruby);
highlightJS.registerLanguage('erb', erb);
highlightJS.registerLanguage('erlang-repl', erlangRepl);
highlightJS.registerLanguage('erlang', erlang);
highlightJS.registerLanguage('excel', excel);
highlightJS.registerLanguage('fsharp', fsharp);
highlightJS.registerLanguage('go', go);
highlightJS.registerLanguage('gradle', gradle);
highlightJS.registerLanguage('groovy', groovy);
highlightJS.registerLanguage('handlebars', handlebars);
highlightJS.registerLanguage('haskell', haskell);
highlightJS.registerLanguage('htmlbars', htmlbars);
highlightJS.registerLanguage('http', http);
highlightJS.registerLanguage('ini', ini);
highlightJS.registerLanguage('java', java);
highlightJS.registerLanguage('javascript', javascript);
highlightJS.registerLanguage('json', json);
highlightJS.registerLanguage('julia', julia);
highlightJS.registerLanguage('julia-repl', juliaRepl);
highlightJS.registerLanguage('kotlin', kotlin);
highlightJS.registerLanguage('less', less);
highlightJS.registerLanguage('lisp', lisp);
highlightJS.registerLanguage('llvm', llvm);
highlightJS.registerLanguage('lua', lua);
highlightJS.registerLanguage('makefile', makefile);
highlightJS.registerLanguage('mathematica', mathematica);
highlightJS.registerLanguage('matlab', matlab);
highlightJS.registerLanguage('perl', perl);
highlightJS.registerLanguage('nginx', nginx);
highlightJS.registerLanguage('nix', nix);
highlightJS.registerLanguage('objectivec', objectivec);
highlightJS.registerLanguage('ocaml', ocaml);
highlightJS.registerLanguage('pgsql', pgsql);
highlightJS.registerLanguage('php', php);
highlightJS.registerLanguage('plaintext', plaintext);
highlightJS.registerLanguage('powershell', powershell);
highlightJS.registerLanguage('properties', properties);
highlightJS.registerLanguage('protobuf', protobuf);
highlightJS.registerLanguage('puppet', puppet);
highlightJS.registerLanguage('python', python);
highlightJS.registerLanguage('r', r);
highlightJS.registerLanguage('reasonml', reasonml);
highlightJS.registerLanguage('rust', rust);
highlightJS.registerLanguage('scala', scala);
highlightJS.registerLanguage('scheme', scheme);
highlightJS.registerLanguage('scss', scss);
highlightJS.registerLanguage('shell', shell);
highlightJS.registerLanguage('sql', sql);
highlightJS.registerLanguage('stylus', stylus);
highlightJS.registerLanguage('swift', swift);
highlightJS.registerLanguage('yaml', yaml);
highlightJS.registerLanguage('tex', tex);
highlightJS.registerLanguage('typescript', typescript);
highlightJS.registerLanguage('vim', vim);
export var hljs = highlightJS;
//# sourceMappingURL=highlight.js-slim.js.map

==> diff2html-3.1.7.jar: META-INF/resources/webjars/diff2html/3.1.7/lib-esm/ui/js/highlight.js-slim.js <==
import highlightJS from 'highlight.js/lib/core';
import cLike from 'highlight.js/lib/languages/c-like';
import cpp from 'highlight.js/lib/languages/cpp';
import xml from 'highlight.js/lib/languages/xml';
import awk from 'highlight.js/lib/languages/awk';
import bash from 'highlight.js/lib/languages/bash';
import c from 'highlight.js/lib/languages/c';
import clojure from 'highlight.js/lib/languages/clojure';
import crystal from 'highlight.js/lib/languages/crystal';
import csharp from 'highlight.js/lib/languages/csharp';
import csp from 'highlight.js/lib/languages/csp';
import css from 'highlight.js/lib/languages/css';
import markdown from 'highlight.js/lib/languages/markdown';
import dart from 'highlight.js/lib/languages/dart';
import diff from 'highlight.js/lib/languages/diff';
import dockerfile from 'highlight.js/lib/languages/dockerfile';
import elixir from 'highlight.js/lib/languages/elixir';
import elm from 'highlight.js/lib/languages/elm';
import ruby from 'highlight.js/lib/languages/ruby';
import erlang from 'highlight.js/lib/languages/erlang';
import fsharp from 'highlight.js/lib/languages/fsharp';
import go from 'highlight.js/lib/languages/go';
import gradle from 'highlight.js/lib/languages/gradle';
import groovy from 'highlight.js/lib/languages/groovy';
import handlebars from 'highlight.js/lib/languages/handlebars';
import haskell from 'highlight.js/lib/languages/haskell';
import ini from 'highlight.js/lib/languages/ini';
import java from 'highlight.js/lib/languages/java';
import javascript from 'highlight.js/lib/languages/javascript';
import json from 'highlight.js/lib/languages/json';
import kotlin from 'highlight.js/lib/languages/kotlin';
import less from 'highlight.js/lib/languages/less';
import lisp from 'highlight.js/lib/languages/lisp';
import lua from 'highlight.js/lib/languages/lua';
import makefile from 'highlight.js/lib/languages/makefile';
import perl from 'highlight.js/lib/languages/perl';
import nginx from 'highlight.js/lib/languages/nginx';
import objectivec from 'highlight.js/lib/languages/objectivec';
import pgsql from 'highlight.js/lib/languages/pgsql';
import php from 'highlight.js/lib/languages/php';
import plaintext from 'highlight.js/lib/languages/plaintext';
import powershell from 'highlight.js/lib/languages/powershell';
import properties from 'highlight.js/lib/languages/properties';
import protobuf from 'highlight.js/lib/languages/protobuf';
import python from 'highlight.js/lib/languages/python';
import rust from 'highlight.js/lib/languages/rust';
import scala from 'highlight.js/lib/languages/scala';
import scss from 'highlight.js/lib/languages/scss';
import shell from 'highlight.js/lib/languages/shell';
import sql from 'highlight.js/lib/languages/sql';
import swift from 'highlight.js/lib/languages/swift';
import yaml from 'highlight.js/lib/languages/yaml';
import typescript from 'highlight.js/lib/languages/typescript';
highlightJS.registerLanguage('c-like', cLike);
highlightJS.registerLanguage('cpp', cpp);
highlightJS.registerLanguage('xml', xml);
highlightJS.registerLanguage('awk', awk);
highlightJS.registerLanguage('bash', bash);
highlightJS.registerLanguage('c', c);
highlightJS.registerLanguage('clojure', clojure);
highlightJS.registerLanguage('crystal', crystal);
highlightJS.registerLanguage('csharp', csharp);
highlightJS.registerLanguage('csp', csp);
highlightJS.registerLanguage('css', css);
highlightJS.registerLanguage('markdown', markdown);
highlightJS.registerLanguage('dart', dart);
highlightJS.registerLanguage('diff', diff);
highlightJS.registerLanguage('dockerfile', dockerfile);
highlightJS.registerLanguage('elixir', elixir);
highlightJS.registerLanguage('elm', elm);
highlightJS.registerLanguage('ruby', ruby);
highlightJS.registerLanguage('erlang', erlang);
highlightJS.registerLanguage('fsharp', fsharp);
highlightJS.registerLanguage('go', go);
highlightJS.registerLanguage('gradle', gradle);
highlightJS.registerLanguage('groovy', groovy);
highlightJS.registerLanguage('handlebars', handlebars);
highlightJS.registerLanguage('haskell', haskell);
highlightJS.registerLanguage('ini', ini);
highlightJS.registerLanguage('java', java);
highlightJS.registerLanguage('javascript', javascript);
highlightJS.registerLanguage('json', json);
highlightJS.registerLanguage('kotlin', kotlin);
highlightJS.registerLanguage('less', less);
highlightJS.registerLanguage('lisp', lisp);
highlightJS.registerLanguage('lua', lua);
highlightJS.registerLanguage('makefile', makefile);
highlightJS.registerLanguage('perl', perl);
highlightJS.registerLanguage('nginx', nginx);
highlightJS.registerLanguage('objectivec', objectivec);
highlightJS.registerLanguage('pgsql', pgsql);
highlightJS.registerLanguage('php', php);
highlightJS.registerLanguage('plaintext', plaintext);
highlightJS.registerLanguage('powershell', powershell);
highlightJS.registerLanguage('properties', properties);
highlightJS.registerLanguage('protobuf', protobuf);
highlightJS.registerLanguage('python', python);
highlightJS.registerLanguage('rust', rust);
highlightJS.registerLanguage('scala', scala);
highlightJS.registerLanguage('scss', scss);
highlightJS.registerLanguage('shell', shell);
highlightJS.registerLanguage('sql', sql);
highlightJS.registerLanguage('swift', swift);
highlightJS.registerLanguage('yaml', yaml);
highlightJS.registerLanguage('typescript', typescript);
export var hljs = highlightJS;
//# sourceMappingURL=highlight.js-slim.js.map
